;; Generated package description from hiddenquote.el  -*- no-byte-compile: t -*-
(define-package "hiddenquote" "1.2.0.20230911.171055" "Major mode for doing hidden quote puzzles" '((emacs "25.1")) :commit "bab642c36875237528e22f559fc8d953773e13a6" :authors '(("Mauro Aranda" . "maurooaranda@gmail.com")) :maintainer '("Mauro Aranda" . "maurooaranda@gmail.com") :keywords '("games") :url "http://mauroaranda.com/puzzles/hidden-quote-puzzle/")
